Name:           hivex
Version:        1.3.3
Release:        %mkrel 1
Summary:        Read and write Windows Registry binary hive files

Group:          Development/Other
License:        LGPLv2
URL:            http://libguestfs.org/
Source0:        http://libguestfs.org/download/%{name}/%{name}-%{version}.tar.gz

# Upstream patch to fix building hivexsh, hivexget commands.
Patch1:         01-Fix-conditional-test-for-HAVE_HIVEXSH.patch


BuildRequires:  perl-devel
BuildRequires:  perl-Test-Simple
BuildRequires:  perl-Test-Pod
BuildRequires:  perl-Test-Pod-Coverage
BuildRequires:  perl-ExtUtils-MakeMaker-Coverage
BuildRequires:  perl-IO-stringy
BuildRequires:  perl-libintl-perl
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  ruby-devel
BuildRequires:  ruby-rake
BuildRequires:  readline-devel
BuildRequires:  libxml2-devel


%description
Hive files are the undocumented binary blobs that Windows uses to
store the Windows Registry on disk.  Hivex is a library that can read
and write to these files.

'hivexsh' is a shell you can use to interactively navigate a hive
binary file.

'hivexregedit' lets you export and merge to the textual regedit
format.

'hivexml' can be used to convert a hive file to a more useful XML
format.

In order to get access to the hive files themselves, you can copy them
from a Windows machine.  They are usually found in
%%systemroot%%\system32\config.  For virtual machines we recommend
using libguestfs or guestfish to copy out these files.  libguestfs
also provides a useful high-level tool called 'virt-win-reg' (based on
hivex technology) which can be used to query specific registry keys in
an existing Windows VM.

For Perl bindings, see 'perl-hivex'.

For OCaml bindings, see 'ocaml-hivex-devel'.

For Ruby bindings, see 'ruby-hivex'.


%package devel
Summary:        Development tools and libraries for %{name}
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig


%description devel
%{name}-devel contains development tools and libraries
for %{name}.


%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Group:         Development/Other
Requires:      %{name} = %{version}-%{release}


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Group:         Development/Other
Requires:      ocaml-%{name} = %{version}-%{release}
Requires:      hivex-devel


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.


%package -n perl-%{name}
Summary:       Perl bindings for %{name}
Group:         Development/Perl
Requires:      %{name} = %{version}-%{release}
Requires:      perl


%description -n perl-%{name}
perl-%{name} contains Perl bindings for %{name}.


%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Group:         Development/Ruby
Requires:      %{name} = %{version}-%{release}
Requires:      ruby(abi) = 1.8
Requires:      ruby
Provides:      ruby(hivex) = %{version}

%{!?ruby_sitelib: %global ruby_sitelib %(ruby -rrbconfig -e "puts Config::CONFIG['sitelibdir']")}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -rrbconfig -e "puts Config::CONFIG['sitearchdir']")}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.



%prep
%setup -q

#patch1 -p1

# python bindings do not build
%build
%configure2_5x --disable-static PYTHON=no 
make

%check
make check

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std 
rm $RPM_BUILD_ROOT%{_libdir}/libhivex.la

# Remove unwanted Perl files:
find $RPM_BUILD_ROOT -name perllocal.pod -delete
find $RPM_BUILD_ROOT -name .packlist -delete
find $RPM_BUILD_ROOT -name '*.bs' -delete
mkdir -p $RPM_BUILD_ROOT/usr/share/man/man3
mv $RPM_BUILD_ROOT/usr/local/share/man/man3/*.3pm $RPM_BUILD_ROOT/usr/share/man/man3/


%find_lang %{name}

%files -f %{name}.lang
%doc README LICENSE
%{_bindir}/hivexget
%{_bindir}/hivexml
%{_bindir}/hivexregedit
%{_bindir}/hivexsh
%{_libdir}/libhivex.so.*
%{_mandir}/man1/hivexget.1*
%{_mandir}/man1/hivexml.1*
%{_mandir}/man1/hivexregedit.1*
%{_mandir}/man1/hivexsh.1*


%files devel
%doc LICENSE
%{_libdir}/libhivex.so
%{_mandir}/man3/hivex.3*
%{_includedir}/hivex.h
%{_libdir}/pkgconfig/hivex.pc


%files -n ocaml-%{name}
%doc README
%{_libdir}/ocaml/hivex
%exclude %{_libdir}/ocaml/hivex/*.a
%exclude %{_libdir}/ocaml/hivex/*.cmxa
%exclude %{_libdir}/ocaml/hivex/*.cmx
%exclude %{_libdir}/ocaml/hivex/*.mli
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner


%files -n ocaml-%{name}-devel
%{_libdir}/ocaml/hivex/*.a
%{_libdir}/ocaml/hivex/*.cmxa
%{_libdir}/ocaml/hivex/*.cmx
%{_libdir}/ocaml/hivex/*.mli


%files -n perl-%{name}
%{_mandir}/man3/*
%perl_sitearch/*


%files -n ruby-%{name}
%doc ruby/doc/site/*
%{ruby_sitelib}/hivex.rb
%{ruby_sitearch}/_hivex.so


%changelog

* Wed Mar 07 2012 malo <malo> 1.3.3-1.mga2
+ Revision: 220694
- new version 1.3.3

* Thu Nov 17 2011 malo <malo> 1.3.2-1.mga2
+ Revision: 168368
- patch from Fedora to fix autoconf
- fix BuildRequires
- fix Source URL
- new version 1.3.2
- added patches from Fedora (allows to build correctly)
- enable Ruby bindings
- spec clean up

* Sun Jun 12 2011 sander85 <sander85> 1.2.2-3.mga2
+ Revision: 104652
- Rebuild for perl 5.14

* Thu Mar 24 2011 boklm <boklm> 1.2.2-2.mga1
+ Revision: 76154
- rebuild for bug #497

* Mon Mar 21 2011 saispo <saispo> 1.2.2-1.mga1
+ Revision: 75279
- imported package hivex

